@@ -323,7 +323,7 @@ class MailBox(BaseMailBox):
                 return imaplib.IMAP4_SSL(self._host, self._port, self._keyfile,  # noqa
                                          self._certfile, self._ssl_context, self._timeout)
 
-    def xoauth2(self, username: str, access_token: str, initial_folder: str = 'INBOX') -> 'BaseMailBox':
+    def xoauth2(self, username: str, access_token: str, initial_folder = 'INBOX') -> 'BaseMailBox':
         """Authenticate to account using OAuth 2.0 mechanism"""
         auth_string = 'user={}\1auth=Bearer {}\1\1'.format(username, access_token)
         result = self.box.authenticate('XOAUTH2', lambda x: auth_string)  # noqa
